changeset 9604:d3f06c8c76a1

(Fdirectory_files): Use the new calling convention for compile_pattern.
author Karl Heuer <kwzh@gnu.org>
date Wed, 19 Oct 1994 04:51:07 +0000
parents 8792d17812fb
children cf97e75d8e02
files src/dired.c
diffstat 1 files changed, 8 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/src/dired.c	Wed Oct 19 03:55:13 1994 +0000
+++ b/src/dired.c	Wed Oct 19 04:51:07 1994 +0000
@@ -80,8 +80,8 @@
 
 #include "regex.h"
 
-/* A search buffer, with a fastmap allocated and ready to go.  */
-extern struct re_pattern_buffer searchbuf;
+/* Returns a search buffer, with a fastmap allocated and ready to go.  */
+extern struct re_pattern_buffer *compile_pattern ();
 
 #define min(a, b) ((a) < (b) ? (a) : (b))
 
@@ -116,6 +116,7 @@
   int length;
   Lisp_Object list, name, dirfilename;
   Lisp_Object handler;
+  struct re_pattern_buffer *bufp;
 
   /* If the file name has special constructs in it,
      call the corresponding file handler.  */
@@ -154,14 +155,14 @@
 	 catching and signalling our own errors, we just call
 	 compile_pattern to do the work for us.  */
 #ifdef VMS
-      compile_pattern (match, &searchbuf, 0,
-		       buffer_defaults.downcase_table->contents);
+      bufp = compile_pattern (match, 0,
+			      buffer_defaults.downcase_table->contents);
 #else
-      compile_pattern (match, &searchbuf, 0, 0);
+      bufp = compile_pattern (match, 0, 0);
 #endif
     }
 
   /* Now searchbuf is the compiled form of MATCH; don't call anything
      which might compile a new regexp until we're done with the loop!  */
 
   /* Do this opendir after anything which might signal an error; if
@@ -186,7 +187,7 @@
       if (DIRENTRY_NONEMPTY (dp))
 	{
 	  if (NILP (match)
-	      || (0 <= re_search (&searchbuf, dp->d_name, len, 0, len, 0)))
+	      || (0 <= re_search (bufp, dp->d_name, len, 0, len, 0)))
 	    {
 	      if (!NILP (full))
 		{
@@ -154,14 +155,14 @@
     }
 
-  /* Now searchbuf is the compiled form of MATCH; don't call anything
+  /* Now *bufp is the compiled form of MATCH; don't call anything
      which might compile a new regexp until we're done with the loop!  */
 